==> indigitall_flutter_plugin-2.0.2.tar.gz: android/src/main/kotlin/com/indigitall/indigitall_flutter_plugin/utils/InAppParse.kt <==
package com.indigitall.indigitall_flutter_plugin.utils
import android.content.Context
import androidx.core.content.ContextCompat
import com.indigitall.android.commons.models.CoreAction
import com.indigitall.android.commons.models.ErrorModel
import com.indigitall.android.inapp.models.InApp
import com.indigitall.android.inapp.models.InAppErrorModel
import com.indigitall.android.inapp.models.InAppProperties
import com.indigitall.android.inapp.models.InAppSchema
import io.flutter.plugin.common.MethodChannel
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject

object InAppParse {
    private val INAPP_CODE = "inAppCode"
    private val SHOWTIME = "showtime"
    private val ACTION_POPUP = "popUpAction"
    private val CALLBACK_GET_INAPP = "callbackGetInApp"
    private val CALLBACK_SHOWTIME_FINISHED = "callbackShowTimeFinished"

    fun inAppToMap(key: String, inAppcode: String?): Map<*, *>{
        val map: MutableMap<String, Any> = HashMap()
        inAppcode?.let{map[INAPP_CODE] = inAppcode}
//    webView?.let{map[WEBVIEW] = webView}
        val inAppMap: MutableMap<String, Map<*,*>> = HashMap()
        inAppMap[key] = map
        return inAppMap
    }

    fun popUpActionToMap(action: String): Map<*, *>{
        val map: MutableMap<String, String> = HashMap()
        map[ACTION_POPUP] = action
        return map
    }

    fun inAppShowTimeFinishedToMap(inAppcode: String?, time: Int): Map<*, *>{
        val map: MutableMap<String, Any> = HashMap()
        map[SHOWTIME] = time
        inAppcode?.let{map[INAPP_CODE] = inAppcode}
//    webView?.let{map[WEBVIEW] = webView}

        val mapShowTime: MutableMap<String, MutableMap<String, Any> > = HashMap()
        mapShowTime[CALLBACK_SHOWTIME_FINISHED] = map
        return mapShowTime
    }

    fun inAppToMap(inApp: InApp):  Map<*, *>{
        val INAPPID = "inAppId"
        val LAST_VERSION_ID = "lastVersionId"
        val SHOW_ONCE = "showOnce"
        val RENEWAL_TIME = "renewalTime"
        val CREATION_DATE = "creationDate"
        val EXPIRED_DATE = "expiredDate"
        val PROPERTIES = "properties"
        val SCHEMA = "schema"
        val INAPP_SHOW = "inAppShow"
        val VERSION = "version"
        val CACHE_TTL = "cacheTtl"
        val CUSTOM_DATA = "customData"

        val map: MutableMap<String, Any> = HashMap()
        inApp.inAppId?.let{map[INAPPID] = it}
        inApp.lastVersionId?.let{map[LAST_VERSION_ID] = it}
        inApp.isShowOnce?.let{map[SHOW_ONCE] = it}
        inApp.cacheTtl?.let{map[CACHE_TTL] = it}
        inApp.version?.let{map[VERSION] = it}
        inApp.customData?.let{map[CUSTOM_DATA] = it}

        inApp.creationDate?.let{map[CREATION_DATE] = it}
        inApp.expiredDate?.let{map[EXPIRED_DATE] = it}
        inApp.properties?.let{
            map[PROPERTIES] = inAppPropertiesToMap(it)
        }
        inApp.schema?.let{
            map[SCHEMA] = inAppSchemaToMap(it)
        }
        val inAppMap: MutableMap<String, Map<*,*>> = HashMap()
        inAppMap[CALLBACK_GET_INAPP] = map
        return inAppMap
    }

    fun inAppPropertiesToMap(inAppProperties: InAppProperties):  Map<*, *>{
        val ACTION = "action"
        val CONTENT_URL = "contentUrl"
        val NUMBER_OF_SHOWS = "numberOfShows"
        val NUMBER_OF_CLICKS = "numberOfClicks"
        val SHOWTIME = "showTime"
        val DISMISS_FOREVER = "dismissForever"
        val LAYOUT = "layout"
        val map: MutableMap<String, Any> = HashMap()
        inAppProperties.action?.let{
            map[ACTION] = inAppActionToMap(it).toString()
        }
        inAppProperties.contentUrl?.let{map[CONTENT_URL] = it}
        inAppProperties.showTime?.let{map[SHOWTIME] = it}
        inAppProperties.numberOfShows?.let{map[NUMBER_OF_SHOWS] = it}
        inAppProperties.numberOfClicks?.let{map[NUMBER_OF_CLICKS] = it}
        inAppProperties.dismissForever?.let{map[DISMISS_FOREVER] = it}
//    inAppProperties.layout?.let{
//      map[LAYOUT] = inAppLayoutToMap(it)
//    }
        return map
    }

    fun inAppSchemaToMap(inAppSchema: InAppSchema):  Map<*, *> {
        val CODE = "code"
        val WIDTH = "width"
        val HEIGHT = "height"
        val map: MutableMap<String, Any> = HashMap()
        inAppSchema.width?.let{map[WIDTH] = it}
        inAppSchema.code?.let{map[CODE] = it}
        inAppSchema.height?.let{map[HEIGHT] = it}
        return map
    }

    fun inAppActionToMap(inAppAction: CoreAction):  JSONObject?{
        return (mapFromAction(inAppAction))
    }

    fun topicToMap(key: String, value: String): Map<*, *>{
        val map: MutableMap<String, String> = HashMap()
        map[key] = value
        return map
    }

    fun parseTopicArray(params: JSONArray?): Array<String?> {
        var topics = arrayOf<String?>()
        try {
            params?.let{
                if (it.length() > 0) {
                    topics = arrayOfNulls(it.length())
                    for (i in 0 until it.length()) {
                        topics[i] = it.getString(i)
                    }
                }
            }
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return topics
    }

    fun mapFromAction(pushAction: CoreAction): JSONObject {
        val MAP_DESTROY = "destroy"
        val MAP_TOPICS = "topics"
        val MAP_TYPE = "type"
        val MAP_TYPE_APP = "app"
        val MAP_TYPE_URL = "url"
        val MAP_TYPE_CALL = "call"
        val MAP_TYPE_MARKET = "market"
        val MAP_TYPE_SHARE = "share"
        val map = JSONObject()
        try {
            pushAction.isDestroy?.let{map.put(MAP_DESTROY, it.toString())}
            pushAction.topics?.let{map.put(MAP_TOPICS,it.toString())}
            pushAction.type?.let{map.put(MAP_TYPE, it.toString())}
            pushAction.app?.let{map.put(MAP_TYPE_APP, it)}
            pushAction.url?.let{map.put(MAP_TYPE_URL, it)}
            pushAction.call?.let{map.put(MAP_TYPE_CALL, it)}
            pushAction.market?.let{map.put(MAP_TYPE_MARKET, it)}
            pushAction.share?.let{map.put(MAP_TYPE_SHARE, it)}
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }

    fun mapInAppError(context: Context?, errorModel: InAppErrorModel?, result: MethodChannel.Result) {
        context?.let {
            ContextCompat.getMainExecutor(it).execute {
                errorModel?.errorCode?.name?.let { it1 -> result.error(it1,
                    errorModel.errorMessage.errorMessage, null) }
            }
        }
    }
    fun mapError(context: Context?, errorModel: ErrorModel?, result: MethodChannel.Result) {
        context?.let {
            ContextCompat.getMainExecutor(it).execute {
                errorModel?.errorCode?.name?.let { it1 -> result.error(it1,
                    errorModel.errorMessage.errorMessage, null) }
            }
        }
    }
}

==> indigitall_flutter_plugin-2.2.0.tar.gz: android/src/main/kotlin/com/indigitall/indigitall_flutter_plugin/utils/InAppParse.kt <==
package com.indigitall.indigitall_flutter_plugin.utils
import android.content.Context
import androidx.core.content.ContextCompat
import com.indigitall.android.commons.models.CoreAction
import com.indigitall.android.commons.models.ErrorModel
import com.indigitall.android.inapp.models.InApp
import com.indigitall.android.inapp.models.InAppErrorModel
import com.indigitall.android.inapp.models.InAppProperties
import com.indigitall.android.inapp.models.InAppSchema
import com.indigitall.android.inapp.models.InAppShow
import io.flutter.plugin.common.MethodChannel
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject

object InAppParse {
    private val INAPP_CODE = "inAppCode"
    private val SHOWTIME = "showtime"
    private val ACTION_POPUP = "popUpAction"
    private val CALLBACK_GET_INAPP = "callbackGetInApp"
    private val CALLBACK_SHOWTIME_FINISHED = "callbackShowTimeFinished"

    fun inAppToMap(key: String, inAppcode: String?): Map<*, *>{
        val map: MutableMap<String, Any> = HashMap()
        inAppcode?.let{map[INAPP_CODE] = inAppcode}
//    webView?.let{map[WEBVIEW] = webView}
        val inAppMap: MutableMap<String, Map<*,*>> = HashMap()
        inAppMap[key] = map
        return inAppMap
    }

    fun popUpActionToMap(action: String): Map<*, *>{
        val map: MutableMap<String, String> = HashMap()
        map[ACTION_POPUP] = action
        return map
    }

    fun inAppShowTimeFinishedToMap(inAppcode: String?, time: Int): Map<*, *>{
        val map: MutableMap<String, Any> = HashMap()
        map[SHOWTIME] = time
        inAppcode?.let{map[INAPP_CODE] = inAppcode}
//    webView?.let{map[WEBVIEW] = webView}

        val mapShowTime: MutableMap<String, MutableMap<String, Any> > = HashMap()
        mapShowTime[CALLBACK_SHOWTIME_FINISHED] = map
        return mapShowTime
    }

    fun inAppToMap(inApp: InApp):  Map<*, *>{
        val INAPPID = "inAppId"
        val LAST_VERSION_ID = "lastVersionId"
        val SHOW_ONCE = "showOnce"
        val RENEWAL_TIME = "renewalTime"
        val CREATION_DATE = "creationDate"
        val EXPIRED_DATE = "expiredDate"
        val PROPERTIES = "properties"
        val SCHEMA = "schema"
        val INAPP_SHOW = "inAppShow"
        val VERSION = "version"
        val CACHE_TTL = "cacheTtl"
        val CUSTOM_DATA = "customData"
        val JSON_INAPP_FILTERS = "filters"
        val JSON_INAPP_NAME = "name"

        val map: MutableMap<String, Any> = HashMap()
        inApp.inAppId?.let{map[INAPPID] = it}
        inApp.lastVersionId?.let{map[LAST_VERSION_ID] = it}
        inApp.isShowOnce?.let{map[SHOW_ONCE] = it}
        inApp.cacheTtl?.let{map[CACHE_TTL] = it}
        inApp.version?.let{map[VERSION] = it}
        inApp.customData?.let{map[CUSTOM_DATA] = it}

        inApp.creationDate?.let{map[CREATION_DATE] = it}
        inApp.expiredDate?.let{map[EXPIRED_DATE] = it}
        inApp.properties?.let{
            map[PROPERTIES] = inAppPropertiesToMap(it)
        }
        inApp.schema?.let{
            map[SCHEMA] = inAppSchemaToMap(it)
        }
        inApp.inAppShow?.let{
            map[INAPP_SHOW] = inAppShowToMap(it)
        }
        inApp.filters?.let { map[JSON_INAPP_FILTERS] = it }
        inApp.name?.let{map[JSON_INAPP_NAME] = it}
        val inAppMap: MutableMap<String, Map<*,*>> = HashMap()
        inAppMap[CALLBACK_GET_INAPP] = map
        return inAppMap
    }

    fun inAppPropertiesToMap(inAppProperties: InAppProperties):  Map<*, *>{
        val ACTION = "action"
        val CONTENT_URL = "contentUrl"
        val NUMBER_OF_SHOWS = "numberOfShows"
        val NUMBER_OF_CLICKS = "numberOfClicks"
        val SHOWTIME = "showTime"
        val DISMISS_FOREVER = "dismissForever"
        val LAYOUT = "layout"
        val map: MutableMap<String, Any> = HashMap()
        inAppProperties.action?.let{
            map[ACTION] = inAppActionToMap(it).toString()
        }
        inAppProperties.contentUrl?.let{map[CONTENT_URL] = it}
        inAppProperties.showTime?.let{map[SHOWTIME] = it}
        inAppProperties.numberOfShows?.let{map[NUMBER_OF_SHOWS] = it}
        inAppProperties.numberOfClicks?.let{map[NUMBER_OF_CLICKS] = it}
        inAppProperties.dismissForever?.let{map[DISMISS_FOREVER] = it}
//    inAppProperties.layout?.let{
//      map[LAYOUT] = inAppLayoutToMap(it)
//    }
        return map
    }

    fun inAppShowToMap(inAppShow: InAppShow) :  Map<*, *> {
        val map: MutableMap<String, Any> = HashMap()
        val JSON_TIMES_SHOWED = "timesShowed"
        val JSON_TIMES_CLICKED = "timesClicked"
        val JSON_WAS_DISMISSED = "wasDismissed"
        try {
            inAppShow.timesShowed?.let{map[JSON_TIMES_SHOWED] = it}
            inAppShow.timesClicked?.let{map[JSON_TIMES_CLICKED] = it}
            inAppShow.wasDismissed?.let{map[JSON_WAS_DISMISSED] = it}

        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }

    fun inAppSchemaToMap(inAppSchema: InAppSchema):  Map<*, *> {
        val CODE = "code"
        val WIDTH = "width"
        val HEIGHT = "height"
        val map: MutableMap<String, Any> = HashMap()
        inAppSchema.width?.let{map[WIDTH] = it}
        inAppSchema.code?.let{map[CODE] = it}
        inAppSchema.height?.let{map[HEIGHT] = it}
        return map
    }

    fun inAppActionToMap(inAppAction: CoreAction):  JSONObject?{
        return (mapFromAction(inAppAction))
    }

    fun topicToMap(key: String, value: String): Map<*, *>{
        val map: MutableMap<String, String> = HashMap()
        map[key] = value
        return map
    }

    fun parseTopicArray(params: JSONArray?): Array<String?> {
        var topics = arrayOf<String?>()
        try {
            params?.let{
                if (it.length() > 0) {
                    topics = arrayOfNulls(it.length())
                    for (i in 0 until it.length()) {
                        topics[i] = it.getString(i)
                    }
                }
            }
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return topics
    }

    fun mapFromAction(pushAction: CoreAction): JSONObject {
        val MAP_DESTROY = "destroy"
        val MAP_TOPICS = "topics"
        val MAP_TYPE = "type"
        val MAP_TYPE_APP = "app"
        val MAP_TYPE_URL = "url"
        val MAP_TYPE_CALL = "call"
        val MAP_TYPE_MARKET = "market"
        val MAP_TYPE_SHARE = "share"
        val MAP_TYPE_WEBVIEW = "webview"

        val map = JSONObject()
        try {
            pushAction.isDestroy()?.let{map.put(MAP_DESTROY, it.toString())}
            pushAction.topics?.let{map.put(MAP_TOPICS,it.toString())}
            pushAction.type?.let{map.put(MAP_TYPE, it.toString())}
            pushAction.app?.let{map.put(MAP_TYPE_APP, it)}
            pushAction.url?.let{map.put(MAP_TYPE_URL, it)}
            pushAction.call?.let{map.put(MAP_TYPE_CALL, it)}
            pushAction.market?.let{map.put(MAP_TYPE_MARKET, it)}
            pushAction.share?.let{map.put(MAP_TYPE_SHARE, it)}
            pushAction.webview?.let{map.put(MAP_TYPE_WEBVIEW, it)}
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }

    fun mapInAppError(context: Context?, errorModel: InAppErrorModel?, result: MethodChannel.Result) {
        context?.let {
            ContextCompat.getMainExecutor(it).execute {
                errorModel?.errorCode?.name?.let { it1 -> result.error(it1,
                    errorModel.errorMessage.errorMessage, null) }
            }
        }
    }
    fun mapError(context: Context?, errorModel: ErrorModel?, result: MethodChannel.Result) {
        context?.let {
            ContextCompat.getMainExecutor(it).execute {
                errorModel?.errorCode?.name?.let { it1 -> result.error(it1,
                    errorModel.errorMessage.errorMessage, null) }
            }
        }
    }
}
